@@ -21,7 +21,7 @@ from __future__ import absolute_import
 from __future__ import print_function
 from __future__ import unicode_literals
 
-__version__ = "1.5.5"
+__version__ = "1.6"
 
 import os
 import math
@@ -45,6 +45,7 @@ SCALE = 0.75
 JOYSTICK_THRESHOLD = 0.7
 
 TEAM_SIZE = 8
+ROUND_TICK = 2
 
 TEAM_RED = 0
 TEAM_GREEN = 1
@@ -75,7 +76,8 @@ MENU_JS_PLAYER1 = 4
 MENU_JS_PLAYER2 = 5
 MENU_ITEMS = {MENU_MAIN: ["1-player", "2-player", "Controls", "Quit"],
               MENU_START: ["1 point", "2 points", "3 points", "4 points",
-                            "5 points", "6 points", "Back"],
+                           "5 points", "6 points", "7 points", "8 points",
+                           "Back"],
               MENU_CONTROLS: ["Player 1 (keyboard)", "Player 1 (joystick)",
                               "Player 2 (keyboard)", "Player 2 (joystick)",
                               "Back"],
@@ -151,6 +153,7 @@ class Room(sge.Room):
 
     def event_room_start(self):
         self.score = 0
+        self.round_counter = 0
         self.started = False
         self.finished = False
         self.multiplayer = False
@@ -314,7 +317,7 @@ class Room(sge.Room):
                     elif self.menu_selection == 3:
                         sge.game.end()
                 elif self.menu == MENU_START:
-                    if self.menu_selection < 6:
+                    if self.menu_selection < 8:
                         points_to_win = self.menu_selection + 1
                         self.update_meter()
                         self.round_start()
@@ -532,9 +535,17 @@ class Room(sge.Room):
         if not music.playing:
             music.play(loops=None)
 
-        for i in range(max(1, TEAM_SIZE - max(self.score, 0))):
+        round_limit = points_to_win * 3 // 2
+        if abs(self.round_counter) >= round_limit:
+            penalty = int((self.round_counter -
+                           math.copysign(round_limit, self.round_counter)) /
+                          ROUND_TICK)
+        else:
+            penalty = 0
+
+        for i in range(max(1, TEAM_SIZE - max(self.score, 0, penalty))):
             Ship.create(TEAM_GREEN)
-        for i in range(max(1, TEAM_SIZE + min(self.score, 0))):
+        for i in range(max(1, TEAM_SIZE + min(self.score, 0, penalty))):
             Ship.create(TEAM_RED)
 
         if self.multiplayer:
@@ -591,6 +602,11 @@ class Room(sge.Room):
 
     def round_end(self):
         if self.started:
+            if self.score > 0:
+                self.round_counter -= 1
+            elif self.score < 0:
+                self.round_counter += 1
+
             if abs(self.score) < points_to_win:
                 self.alarms["round_end"] = 90
             else:
@@ -717,46 +733,42 @@ class Ship(sge.Object):
         self.can_shoot = True
         self.rvelocity = 0
         self.thrust_obj = None
-        self.delta_mult = 0
         ships_lists[self.team].append(self)
 
     def event_update_position(self, delta_mult):
-        self.delta_mult += delta_mult
-
-        for i in range(int(self.delta_mult)):
-            # Turning
-            if self.left - self.right:
-                self.rvelocity += (self.left - self.right) * TURN
-                if self.rvelocity < -TURN_MAX:
-                    self.rvelocity = -TURN_MAX
-                elif self.rvelocity > TURN_MAX:
-                    self.rvelocity = TURN_MAX
-
-            self.image_rotation += self.rvelocity
-
-            if abs(self.rvelocity) > TURN_FRICTION:
-                s = self.rvelocity / abs(self.rvelocity)
-                self.rvelocity -= s * TURN_FRICTION
+        if delta_mult:
+            vi = self.rvelocity
+            a = (self.left - self.right) * TURN
+            self.rvelocity += a * delta_mult
+            dc = -math.copysign(TURN_FRICTION * delta_mult, self.rvelocity)
+            if abs(self.rvelocity) > abs(dc):
+                a -= math.copysign(TURN_FRICTION, self.rvelocity)
+                self.rvelocity += dc
             else:
+                a -= self.rvelocity / delta_mult
                 self.rvelocity = 0
 
-            # Thrusting
-            if self.thrust:
-                direction = self.image_rotation + 90
-                self.xvelocity += math.cos(math.radians(direction)) * THRUST
-                self.yvelocity -= math.sin(math.radians(direction)) * THRUST
-                self.speed = min(self.speed, THRUST_MAX)
-
-            self.x += self.xvelocity
-            self.y += self.yvelocity
-
-        self.delta_mult -= int(self.delta_mult)
+            self.image_rotation += vi * delta_mult + 0.5 * a * (delta_mult ** 2)
+            super(Ship, self).event_update_position(delta_mult)
 
     def event_step(self, time_passed, delta_mult):
         # Shoot
         if self.shoot:
             self.do_shoot()
 
+        # Acceleration
+        if self.thrust:
+            direction = math.radians(self.image_rotation + 90)
+            self.xacceleration = math.cos(direction) * THRUST
+            self.yacceleration = -math.sin(direction) * THRUST
+        else:
+            self.xacceleration = 0
+            self.yacceleration = 0
+
+        self.speed = min(self.speed, THRUST_MAX)
+        if abs(self.rvelocity) > TURN_MAX:
+            self.rvelocity = math.copysign(TURN_MAX, self.rvelocity)
+
         # Bounce off edges
         if self.bbox_left < 0:
             self.bbox_left *= -1
@@ -799,7 +811,7 @@ class Ship(sge.Object):
         if alarm_id == "shoot":
             self.can_shoot = True
 
-    def event_collision(self, other):
+    def event_collision(self, other, xdirection, ydirection):
         if isinstance(other, Bullet) and other.team != self.team:
             self.destroy()
             Explosion.create(self.x, self.y, self.z, sprite=explosion_sprite,
@@ -887,7 +899,7 @@ class Bullet(sge.Object):
         if alarm_id == "death":
             self.destroy()
 
-    def event_collision(self, other):
+    def event_collision(self, other, xdirection, ydirection):
         if isinstance(other, Ship) and other.team != self.team:
             self.destroy()
         elif isinstance(other, Bullet):
